##  Activate SAP LeanIX Architecture and Road Map Planning
SAP LeanIX Architecture and Road Map Planning is a separate product that you can include in your SAP LeanIX workspace. If it is not already included in your contract, you can reach out to your SAP LeanIX Customer Success Manager for further action.
Once SAP LeanIX Architecture and Road Map Planning has been added to your workspace, activation is available in a self-opt way.
  1. Navigate to Administration > Optional Features & Early Access.
  2. Click Activate next to SAP LeanIX Architecture and Road Map Planning.
![Activating BTM Module](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27538eb57a4410149013b92ce4e13927_LowRes.png)
Activating SAP LeanIX Architecture and Road Map Planning (Previously known as BTM module)


Upon activating SAP LeanIX Architecture and Road Map Planning, all its features, such as Milestones, Transformations, Impacts, etc., are automatically enabled. To learn more about Milestones, Transformations, and Impacts, see [Milestones](https://help.sap.com/docs/leanix/ea/milestones?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to add and manage milestones and realize their value by effectively visualizing them in reports."), [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet."), and [Impacts](https://help.sap.com/docs/leanix/ea/impacts?locale=en-US&state=PRODUCTION&version=CLOUD "Impacts detail the changes at attribute and relation levels. Learn how to manage these Impacts in SAP LeanIX Architecture and Road Map Planning.").
